==> zjkj-wzxt-impl-3.0.0-20240801.022331-13-sources.jar: com/ejianc/wzxt/plan/bean/MonthPlanDetailEntity.java <==
package com.ejianc.wzxt.plan.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 材料月计划-子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_month_plan_detail")
public class MonthPlanDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="material_month_plan_id")
    private Long materialMonthPlanId; // 所属月计划Id
    @TableField(value="material_category_id")
    private Long materialCategoryId; // 物资分类Id
    @TableField(value="material_category_name")
    private String materialCategoryName; // 物资分类名称
    @TableField(value="material_id")
    private Long materialId; // 物资Id
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="unit")
    private String unit; // 计量单位
    @TableField(value="change_type")
    private Integer changeType; // 变更类型: 1-增补项，2-删除项，3-变更项
    @TableField(value="target_id")
    private Long targetId; // 变更项原数据Id
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="material_code")
    private String materialCode; // 物资编码
    @TableField(value="unit_id")
    private Long unitId; // 计量单位Id
    @TableField(value="plan_total_num")
    private BigDecimal planTotalNum; // 总控计划量
    @TableField(value="plan_total_surplus_num")
    private BigDecimal planTotalSurplusNum; // 总控剩余量
    @TableField(value="plan_month_num")
    private BigDecimal planMonthNum; // 月计划量
    @TableField(value="order_num")
    private BigDecimal orderNum; // 订单量
    @TableField(value="check_num")
    private BigDecimal checkNum; // 订单验收量
    @TableField(value="self_check_num")
    private BigDecimal selfCheckNum; // 自制验收量
    
    
    

    public Long getMaterialMonthPlanId() {
        return materialMonthPlanId;
    }

    public void setMaterialMonthPlanId(Long materialMonthPlanId) {
        this.materialMonthPlanId = materialMonthPlanId;
    }
    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public Integer getChangeType() {
        return changeType;
    }

    public void setChangeType(Integer changeType) {
        this.changeType = changeType;
    }
    public Long getTargetId() {
        return targetId;
    }

    public void setTargetId(Long targetId) {
        this.targetId = targetId;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public BigDecimal getPlanTotalNum() {
        return planTotalNum;
    }

    public void setPlanTotalNum(BigDecimal planTotalNum) {
        this.planTotalNum = planTotalNum;
    }
    public BigDecimal getPlanTotalSurplusNum() {
        return planTotalSurplusNum;
    }

    public void setPlanTotalSurplusNum(BigDecimal planTotalSurplusNum) {
        this.planTotalSurplusNum = planTotalSurplusNum;
    }
    public BigDecimal getPlanMonthNum() {
        return planMonthNum;
    }

    public void setPlanMonthNum(BigDecimal planMonthNum) {
        this.planMonthNum = planMonthNum;
    }
    public BigDecimal getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(BigDecimal orderNum) {
        this.orderNum = orderNum;
    }
    public BigDecimal getCheckNum() {
        return checkNum;
    }

    public void setCheckNum(BigDecimal checkNum) {
        this.checkNum = checkNum;
    }
    public BigDecimal getSelfCheckNum() {
        return selfCheckNum;
    }

    public void setSelfCheckNum(BigDecimal selfCheckNum) {
        this.selfCheckNum = selfCheckNum;
    }
    
}

==> zjkj-wzxt-impl-3.0.0-20240808.061301-48-sources.jar: com/ejianc/wzxt/plan/bean/MonthPlanDetailEntity.java <==
package com.ejianc.wzxt.plan.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 材料月计划-子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_month_plan_detail")
public class MonthPlanDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="material_month_plan_id")
    private Long materialMonthPlanId; // 所属月计划Id
    @TableField(value="material_category_id")
    private Long materialCategoryId; // 物资分类Id
    @TableField(value="material_category_name")
    private String materialCategoryName; // 物资分类名称
    @TableField(value="material_id")
    private Long materialId; // 物资Id
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="unit")
    private String unit; // 计量单位
    @TableField(value="change_type")
    private Integer changeType; // 变更类型: 1-增补项，2-删除项，3-变更项
    @TableField(value="target_id")
    private Long targetId; // 变更项原数据Id
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="material_code")
    private String materialCode; // 物资编码
    @TableField(value="unit_id")
    private Long unitId; // 计量单位Id
    @TableField(value="plan_total_num")
    private BigDecimal planTotalNum; // 总控计划量
    @TableField(value="plan_total_surplus_num")
    private BigDecimal planTotalSurplusNum; // 总控剩余量
    @TableField(value="plan_month_num")
    private BigDecimal planMonthNum; // 月计划量
    @TableField(value="order_num")
    private BigDecimal orderNum; // 订单量
    @TableField(value="check_num")
    private BigDecimal checkNum; // 订单验收量
    @TableField(value="self_check_num")
    private BigDecimal selfCheckNum; // 自制验收量
    @TableField(exist=false)
    private BigDecimal surplusMonthNum; // 剩余月计划量


    public BigDecimal getSurplusMonthNum() {
        return surplusMonthNum;
    }

    public void setSurplusMonthNum(BigDecimal surplusMonthNum) {
        this.surplusMonthNum = surplusMonthNum;
    }
    

    public Long getMaterialMonthPlanId() {
        return materialMonthPlanId;
    }

    public void setMaterialMonthPlanId(Long materialMonthPlanId) {
        this.materialMonthPlanId = materialMonthPlanId;
    }
    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public Integer getChangeType() {
        return changeType;
    }

    public void setChangeType(Integer changeType) {
        this.changeType = changeType;
    }
    public Long getTargetId() {
        return targetId;
    }

    public void setTargetId(Long targetId) {
        this.targetId = targetId;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public BigDecimal getPlanTotalNum() {
        return planTotalNum;
    }

    public void setPlanTotalNum(BigDecimal planTotalNum) {
        this.planTotalNum = planTotalNum;
    }
    public BigDecimal getPlanTotalSurplusNum() {
        return planTotalSurplusNum;
    }

    public void setPlanTotalSurplusNum(BigDecimal planTotalSurplusNum) {
        this.planTotalSurplusNum = planTotalSurplusNum;
    }
    public BigDecimal getPlanMonthNum() {
        return planMonthNum;
    }

    public void setPlanMonthNum(BigDecimal planMonthNum) {
        this.planMonthNum = planMonthNum;
    }
    public BigDecimal getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(BigDecimal orderNum) {
        this.orderNum = orderNum;
    }
    public BigDecimal getCheckNum() {
        return checkNum;
    }

    public void setCheckNum(BigDecimal checkNum) {
        this.checkNum = checkNum;
    }
    public BigDecimal getSelfCheckNum() {
        return selfCheckNum;
    }

    public void setSelfCheckNum(BigDecimal selfCheckNum) {
        this.selfCheckNum = selfCheckNum;
    }
    
}
